@@ -1,20 +1,18 @@
 /* BSE - Bedevilled Sound Engine
  * Copyright (C) 2004 Tim Janik
  *
- * This program is free software; you can redistribute it and/or
+ * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * A copy of the GNU Lesser General Public License should ship along
+ * with this library; if not, see http://www.gnu.org/copyleft/.
  */
 #include "configure.h"
 #include "bsepcmdevice-alsa.h"
@@ -31,7 +29,7 @@
 #error  unsupported byte order in G_BYTE_ORDER
 #endif
 
-static BIRNET_MSG_TYPE_DEFINE (debug_pcm, "pcm", BIRNET_MSG_DEBUG, NULL);
+static SFI_MSG_TYPE_DEFINE (debug_pcm, "pcm", SFI_MSG_DEBUG, NULL);
 #define DEBUG(...) sfi_debug (debug_pcm, __VA_ARGS__)
 
 
@@ -70,7 +68,7 @@ static guint            alsa_device_latency             (BsePcmHandle
 static const char type_blurb[] = ("PCM driver implementation for the Advanced Linux Sound Architecture "
                                   "(http://alsa-project.org/alsa-doc/alsa-lib/pcm.html)");
 BSE_REGISTER_OBJECT (BsePcmDeviceALSA, BsePcmDevice, NULL, "", type_blurb, NULL, bse_pcm_device_alsa_class_init, NULL, bse_pcm_device_alsa_init);
-BSE_DEFINE_EXPORTS (__FILE__);
+BSE_DEFINE_EXPORTS ();
 
 /* --- variables --- */
 static gpointer parent_class = NULL;
@@ -518,11 +516,11 @@ alsa_device_write (BsePcmHandle *handle,
       gssize n = 0;                                             /* in frames */
       do
         {
-          if (n < 0)    /* errors during read, could be underrun (-EPIPE) */
+          if (n < 0)    /* errors during write, could be overrun (-EPIPE) */
             {
               DEBUG ("ALSA: write() error: %s", snd_strerror (n));
               snd_lib_error_set_handler (silent_error_handler);
-              snd_pcm_prepare (alsa->read_handle);  /* force retrigger */
+              snd_pcm_prepare (alsa->write_handle);  /* force retrigger */
               snd_lib_error_set_handler (NULL);
               return;
             }
